import {
    CanActivate, Router,
    ActivatedRouteSnapshot,
    RouterStateSnapshot
} from '@angular/router';
import { AuthentificationService } from '../api/authentification.service';
import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { InfosUser } from '../models/InfosUser';
import { delay, shareReplay, tap } from 'rxjs/operators';
import { environment } from 'src/environments/environment';

@Injectable({
    providedIn: 'root',
  })

export class AuthGuard implements CanActivate {
    infosUser: Observable<InfosUser> | undefined;
    isLoggedIn : boolean | undefined;
    redirectUrl : string = 'connexion';
    public constructor(
        private readonly authService: AuthentificationService, private readonly router: Router) { }

    canActivate(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): boolean {
        const url: string = state.url;
        return this.checkLogin(url);
    }

    private checkLogin(url: string): boolean {
        this.isLoggedIn = JSON.parse(localStorage.getItem('connexion') || '{}');
        if (this.isLoggedIn) { return true; }
        this.redirectUrl = url;
        this.router.navigate(['/connexion']);

        return false;
    }

    public login(name: string, password: string): Observable<boolean> {
        this.infosUser = this.authService.obtenirUser(name)
        .pipe(shareReplay(1));
        this.infosUser.subscribe((e) =>{
        e.isLogin = e.personneId.toString() === name  && password == '123456';
        localStorage.setItem('connexion', JSON.stringify(e.isLogin));
        })
        return of(true)
        .pipe(
        delay(1000),
            tap(val => this.isLoggedIn = this.isLoggedIn));
    }
      
      
    public obtenirUserConnecter(){
        return this.infosUser;
    }

    public accessToken(userName: string){
        this.authService.accessToken(userName, environment.userRole).subscribe((e: any) => {
            localStorage.setItem('access_token', JSON.stringify(e.access_token));
            localStorage.setItem('refresh_token', JSON.stringify(e.refresh_token));
        }); 
    }
}
