import { Component, OnInit } from '@angular/core';
import { FormControl, Validators, FormGroup } from '@angular/forms';
import { Router } from '@angular/router';
import { environment } from 'src/environments/environment';
import { AuthGuard } from '../facade/authGuard.service';

@Component({
  selector: 'app-authentification',
  templateUrl: './authentification.component.html',
  styleUrls: ['./authentification.component.css']
})
export class AuthentificationComponent implements OnInit {
  message = 'Vous êtes déconnecté. (poc angular)';
  messageConnexion = 'Vous êtes connecté.';
  messageConnexionRefuse = 'Identifiant ou mot de passe incorrect.';
  messageConnexionEncours = 'Tentative de connexion en cours ...';
  title = 'Connexion';
  environnement = environment.title;

  public authentificationForm = new FormGroup({
    nomUtilisateur: new FormControl('', [Validators.required, Validators.minLength(5)]),
    motDePasse: new FormControl('', [Validators.required, Validators.minLength(5), Validators.pattern('(123456)')])
  });


  constructor(public authService: AuthGuard, private router: Router) {}
  
  ngOnInit(): void {
    
  }

  public get nomUtilisateur() {
    return this.authentificationForm.get('nomUtilisateur');
  }

  public get motDePasse() {
    return this.authentificationForm.get('motDePasse');
  }


  setMessage() {
    this.message = this.authService.isLoggedIn ?
    this.messageConnexion : this.messageConnexionRefuse;
  }

  login() {
    this.message = this.messageConnexionEncours;
  
      this.authService.login(this.nomUtilisateur?.value, this.motDePasse?.value).subscribe(() => {
        if (this.authService.isLoggedIn) {
          const redirect = this.authService.redirectUrl ? this.authService.redirectUrl : 'items';
          this.router.navigate([redirect]);

        } else {
          this.message = this.messageConnexionRefuse;
          this.motDePasse?.reset();
        }
      }); 
    
  }

}
